# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from perun.connector.perun_openapi.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from perun.connector.perun_openapi.model.action_type import ActionType
from perun.connector.perun_openapi.model.add_user_ext_source_input import (
    AddUserExtSourceInput,
)
from perun.connector.perun_openapi.model.app_state import AppState
from perun.connector.perun_openapi.model.app_type import AppType
from perun.connector.perun_openapi.model.application import Application
from perun.connector.perun_openapi.model.application_form import ApplicationForm
from perun.connector.perun_openapi.model.application_form_item import (
    ApplicationFormItem,
)
from perun.connector.perun_openapi.model.application_form_item_data import (
    ApplicationFormItemData,
)
from perun.connector.perun_openapi.model.application_mail import ApplicationMail
from perun.connector.perun_openapi.model.applications_order_column import (
    ApplicationsOrderColumn,
)
from perun.connector.perun_openapi.model.applications_page_query import (
    ApplicationsPageQuery,
)
from perun.connector.perun_openapi.model.assigned_group import AssignedGroup
from perun.connector.perun_openapi.model.assigned_member import AssignedMember
from perun.connector.perun_openapi.model.assigned_resource import AssignedResource
from perun.connector.perun_openapi.model.attribute import Attribute
from perun.connector.perun_openapi.model.attribute_action import AttributeAction
from perun.connector.perun_openapi.model.attribute_definition import AttributeDefinition
from perun.connector.perun_openapi.model.attribute_policy import AttributePolicy
from perun.connector.perun_openapi.model.attribute_policy_collection import (
    AttributePolicyCollection,
)
from perun.connector.perun_openapi.model.attribute_rights import AttributeRights
from perun.connector.perun_openapi.model.attribute_rules import AttributeRules
from perun.connector.perun_openapi.model.audit_event import AuditEvent
from perun.connector.perun_openapi.model.audit_message import AuditMessage
from perun.connector.perun_openapi.model.audit_messages_page_query import (
    AuditMessagesPageQuery,
)
from perun.connector.perun_openapi.model.auditable import Auditable
from perun.connector.perun_openapi.model.author import Author
from perun.connector.perun_openapi.model.authorship import Authorship
from perun.connector.perun_openapi.model.authz_roles import AuthzRoles
from perun.connector.perun_openapi.model.ban import Ban
from perun.connector.perun_openapi.model.ban_on_facility import BanOnFacility
from perun.connector.perun_openapi.model.ban_on_resource import BanOnResource
from perun.connector.perun_openapi.model.ban_on_vo import BanOnVo
from perun.connector.perun_openapi.model.brand import Brand
from perun.connector.perun_openapi.model.candidate import Candidate
from perun.connector.perun_openapi.model.category import Category
from perun.connector.perun_openapi.model.consent import Consent
from perun.connector.perun_openapi.model.consent_hub import ConsentHub
from perun.connector.perun_openapi.model.consent_status import ConsentStatus
from perun.connector.perun_openapi.model.destination import Destination
from perun.connector.perun_openapi.model.destination_propagation_type import (
    DestinationPropagationType,
)
from perun.connector.perun_openapi.model.destination_type import DestinationType
from perun.connector.perun_openapi.model.enriched_ban_on_facility import (
    EnrichedBanOnFacility,
)
from perun.connector.perun_openapi.model.enriched_ban_on_resource import (
    EnrichedBanOnResource,
)
from perun.connector.perun_openapi.model.enriched_ban_on_vo import EnrichedBanOnVo
from perun.connector.perun_openapi.model.enriched_ext_source import EnrichedExtSource
from perun.connector.perun_openapi.model.enriched_facility import EnrichedFacility
from perun.connector.perun_openapi.model.enriched_group import EnrichedGroup
from perun.connector.perun_openapi.model.enriched_host import EnrichedHost
from perun.connector.perun_openapi.model.enriched_identity import EnrichedIdentity
from perun.connector.perun_openapi.model.enriched_resource import EnrichedResource
from perun.connector.perun_openapi.model.enriched_vo import EnrichedVo
from perun.connector.perun_openapi.model.entityless_attributes_by_keys import (
    EntitylessAttributesByKeys,
)
from perun.connector.perun_openapi.model.ext_source import ExtSource
from perun.connector.perun_openapi.model.ext_source_object import ExtSourceObject
from perun.connector.perun_openapi.model.facility import Facility
from perun.connector.perun_openapi.model.facility_propagation_state import (
    FacilityPropagationState,
)
from perun.connector.perun_openapi.model.facility_state import FacilityState
from perun.connector.perun_openapi.model.facility_with_attributes import (
    FacilityWithAttributes,
)
from perun.connector.perun_openapi.model.gen_data_node import GenDataNode
from perun.connector.perun_openapi.model.gen_member_data_node import GenMemberDataNode
from perun.connector.perun_openapi.model.graph_dto import GraphDTO
from perun.connector.perun_openapi.model.graph_file_format import GraphFileFormat
from perun.connector.perun_openapi.model.group import Group
from perun.connector.perun_openapi.model.group_member_data import GroupMemberData
from perun.connector.perun_openapi.model.group_member_relation import (
    GroupMemberRelation,
)
from perun.connector.perun_openapi.model.group_resource_status import (
    GroupResourceStatus,
)
from perun.connector.perun_openapi.model.groups_order_column import GroupsOrderColumn
from perun.connector.perun_openapi.model.groups_page_query import GroupsPageQuery
from perun.connector.perun_openapi.model.hashed_gen_data import HashedGenData
from perun.connector.perun_openapi.model.host import Host
from perun.connector.perun_openapi.model.identity import Identity
from perun.connector.perun_openapi.model.input_add_application_mail_for_group import (
    InputAddApplicationMailForGroup,
)
from perun.connector.perun_openapi.model.input_add_application_mail_for_vo import (
    InputAddApplicationMailForVo,
)
from perun.connector.perun_openapi.model.input_add_destination_to_multiple_services import (
    InputAddDestinationToMultipleServices,
)
from perun.connector.perun_openapi.model.input_add_destinations_defined_by_hosts_on_facility import (
    InputAddDestinationsDefinedByHostsOnFacility,
)
from perun.connector.perun_openapi.model.input_add_member_candidates import (
    InputAddMemberCandidates,
)
from perun.connector.perun_openapi.model.input_assign_resource_tag_to_resource import (
    InputAssignResourceTagToResource,
)
from perun.connector.perun_openapi.model.input_assign_resource_tags_to_resource import (
    InputAssignResourceTagsToResource,
)
from perun.connector.perun_openapi.model.input_attribute_definition import (
    InputAttributeDefinition,
)
from perun.connector.perun_openapi.model.input_attribute_policy_collections import (
    InputAttributePolicyCollections,
)
from perun.connector.perun_openapi.model.input_attribute_rights import (
    InputAttributeRights,
)
from perun.connector.perun_openapi.model.input_block_services_on_destinations import (
    InputBlockServicesOnDestinations,
)
from perun.connector.perun_openapi.model.input_change_non_authz_password_by_token import (
    InputChangeNonAuthzPasswordByToken,
)
from perun.connector.perun_openapi.model.input_change_password_for_login import (
    InputChangePasswordForLogin,
)
from perun.connector.perun_openapi.model.input_change_password_for_user import (
    InputChangePasswordForUser,
)
from perun.connector.perun_openapi.model.input_check_password_strength import (
    InputCheckPasswordStrength,
)
from perun.connector.perun_openapi.model.input_consolidate import InputConsolidate
from perun.connector.perun_openapi.model.input_copy_resource import InputCopyResource
from perun.connector.perun_openapi.model.input_create_alternative_password import (
    InputCreateAlternativePassword,
)
from perun.connector.perun_openapi.model.input_create_attribute_definition import (
    InputCreateAttributeDefinition,
)
from perun.connector.perun_openapi.model.input_create_authorship import (
    InputCreateAuthorship,
)
from perun.connector.perun_openapi.model.input_create_category import (
    InputCreateCategory,
)
from perun.connector.perun_openapi.model.input_create_category_nr import (
    InputCreateCategoryNR,
)
from perun.connector.perun_openapi.model.input_create_member_for_candidate import (
    InputCreateMemberForCandidate,
)
from perun.connector.perun_openapi.model.input_create_member_for_user import (
    InputCreateMemberForUser,
)
from perun.connector.perun_openapi.model.input_create_member_from_ext_source import (
    InputCreateMemberFromExtSource,
)
from perun.connector.perun_openapi.model.input_create_owner import InputCreateOwner
from perun.connector.perun_openapi.model.input_create_publication import (
    InputCreatePublication,
)
from perun.connector.perun_openapi.model.input_create_publication_system import (
    InputCreatePublicationSystem,
)
from perun.connector.perun_openapi.model.input_create_resource_tag_with_resource_tag import (
    InputCreateResourceTagWithResourceTag,
)
from perun.connector.perun_openapi.model.input_create_service import InputCreateService
from perun.connector.perun_openapi.model.input_create_service_user import (
    InputCreateServiceUser,
)
from perun.connector.perun_openapi.model.input_create_services_package import (
    InputCreateServicesPackage,
)
from perun.connector.perun_openapi.model.input_create_sponsored_member import (
    InputCreateSponsoredMember,
)
from perun.connector.perun_openapi.model.input_create_sponsored_member_from_csv import (
    InputCreateSponsoredMemberFromCSV,
)
from perun.connector.perun_openapi.model.input_create_sponsored_members import (
    InputCreateSponsoredMembers,
)
from perun.connector.perun_openapi.model.input_create_thanks import InputCreateThanks
from perun.connector.perun_openapi.model.input_create_vo_with_vo import (
    InputCreateVoWithVo,
)
from perun.connector.perun_openapi.model.input_delete_groups import InputDeleteGroups
from perun.connector.perun_openapi.model.input_delete_resource_tag import (
    InputDeleteResourceTag,
)
from perun.connector.perun_openapi.model.input_entityless_attribute import (
    InputEntitylessAttribute,
)
from perun.connector.perun_openapi.model.input_form_item_data import InputFormItemData
from perun.connector.perun_openapi.model.input_form_items_data import InputFormItemsData
from perun.connector.perun_openapi.model.input_get_all_resources_by_resource_tag import (
    InputGetAllResourcesByResourceTag,
)
from perun.connector.perun_openapi.model.input_get_facilities import InputGetFacilities
from perun.connector.perun_openapi.model.input_get_match_resources import (
    InputGetMatchResources,
)
from perun.connector.perun_openapi.model.input_get_members_by_user_attributes import (
    InputGetMembersByUserAttributes,
)
from perun.connector.perun_openapi.model.input_get_messages_page import (
    InputGetMessagesPage,
)
from perun.connector.perun_openapi.model.input_get_paginated_applications import (
    InputGetPaginatedApplications,
)
from perun.connector.perun_openapi.model.input_get_paginated_groups import (
    InputGetPaginatedGroups,
)
from perun.connector.perun_openapi.model.input_get_paginated_members import (
    InputGetPaginatedMembers,
)
from perun.connector.perun_openapi.model.input_get_paginated_subgroups import (
    InputGetPaginatedSubgroups,
)
from perun.connector.perun_openapi.model.input_get_paginated_users import (
    InputGetPaginatedUsers,
)
from perun.connector.perun_openapi.model.input_get_resources import InputGetResources
from perun.connector.perun_openapi.model.input_get_users import InputGetUsers
from perun.connector.perun_openapi.model.input_invitations_from_csv import (
    InputInvitationsFromCsv,
)
from perun.connector.perun_openapi.model.input_invite_member_candidates import (
    InputInviteMemberCandidates,
)
from perun.connector.perun_openapi.model.input_lock_publications import (
    InputLockPublications,
)
from perun.connector.perun_openapi.model.input_remove_resource_tag_from_resource import (
    InputRemoveResourceTagFromResource,
)
from perun.connector.perun_openapi.model.input_remove_resource_tags_from_resource import (
    InputRemoveResourceTagsFromResource,
)
from perun.connector.perun_openapi.model.input_remove_rich_destinations import (
    InputRemoveRichDestinations,
)
from perun.connector.perun_openapi.model.input_reserve_password_for_login import (
    InputReservePasswordForLogin,
)
from perun.connector.perun_openapi.model.input_reserve_password_for_user import (
    InputReservePasswordForUser,
)
from perun.connector.perun_openapi.model.input_send_message import InputSendMessage
from perun.connector.perun_openapi.model.input_set_ban import InputSetBan
from perun.connector.perun_openapi.model.input_set_ban_for_user_on_facility import (
    InputSetBanForUserOnFacility,
)
from perun.connector.perun_openapi.model.input_set_facility_attribute import (
    InputSetFacilityAttribute,
)
from perun.connector.perun_openapi.model.input_set_facility_attributes import (
    InputSetFacilityAttributes,
)
from perun.connector.perun_openapi.model.input_set_facility_resource_group_user_member_attributes import (
    InputSetFacilityResourceGroupUserMemberAttributes,
)
from perun.connector.perun_openapi.model.input_set_facility_resource_user_member_attributes import (
    InputSetFacilityResourceUserMemberAttributes,
)
from perun.connector.perun_openapi.model.input_set_facility_user_attributes import (
    InputSetFacilityUserAttributes,
)
from perun.connector.perun_openapi.model.input_set_group_attribute import (
    InputSetGroupAttribute,
)
from perun.connector.perun_openapi.model.input_set_group_attributes import (
    InputSetGroupAttributes,
)
from perun.connector.perun_openapi.model.input_set_group_resource_attribute import (
    InputSetGroupResourceAttribute,
)
from perun.connector.perun_openapi.model.input_set_group_resource_attributes import (
    InputSetGroupResourceAttributes,
)
from perun.connector.perun_openapi.model.input_set_host_attribute import (
    InputSetHostAttribute,
)
from perun.connector.perun_openapi.model.input_set_host_attributes import (
    InputSetHostAttributes,
)
from perun.connector.perun_openapi.model.input_set_member_attribute import (
    InputSetMemberAttribute,
)
from perun.connector.perun_openapi.model.input_set_member_attributes import (
    InputSetMemberAttributes,
)
from perun.connector.perun_openapi.model.input_set_member_group_attribute import (
    InputSetMemberGroupAttribute,
)
from perun.connector.perun_openapi.model.input_set_member_group_attributes import (
    InputSetMemberGroupAttributes,
)
from perun.connector.perun_openapi.model.input_set_member_group_with_user_attributes import (
    InputSetMemberGroupWithUserAttributes,
)
from perun.connector.perun_openapi.model.input_set_member_resource_and_user_attributes import (
    InputSetMemberResourceAndUserAttributes,
)
from perun.connector.perun_openapi.model.input_set_member_resource_attribute import (
    InputSetMemberResourceAttribute,
)
from perun.connector.perun_openapi.model.input_set_member_resource_attributes import (
    InputSetMemberResourceAttributes,
)
from perun.connector.perun_openapi.model.input_set_member_with_user_attributes import (
    InputSetMemberWithUserAttributes,
)
from perun.connector.perun_openapi.model.input_set_resource_attribute import (
    InputSetResourceAttribute,
)
from perun.connector.perun_openapi.model.input_set_resource_attributes import (
    InputSetResourceAttributes,
)
from perun.connector.perun_openapi.model.input_set_resource_group_attributes import (
    InputSetResourceGroupAttributes,
)
from perun.connector.perun_openapi.model.input_set_resource_group_with_group_attributes import (
    InputSetResourceGroupWithGroupAttributes,
)
from perun.connector.perun_openapi.model.input_set_sending_enabled import (
    InputSetSendingEnabled,
)
from perun.connector.perun_openapi.model.input_set_sponsored_member import (
    InputSetSponsoredMember,
)
from perun.connector.perun_openapi.model.input_set_user_attribute import (
    InputSetUserAttribute,
)
from perun.connector.perun_openapi.model.input_set_user_attributes import (
    InputSetUserAttributes,
)
from perun.connector.perun_openapi.model.input_set_user_ext_source_attribute import (
    InputSetUserExtSourceAttribute,
)
from perun.connector.perun_openapi.model.input_set_user_ext_source_attributes import (
    InputSetUserExtSourceAttributes,
)
from perun.connector.perun_openapi.model.input_set_user_facility_attribute import (
    InputSetUserFacilityAttribute,
)
from perun.connector.perun_openapi.model.input_set_user_facility_attributes import (
    InputSetUserFacilityAttributes,
)
from perun.connector.perun_openapi.model.input_set_vo_attribute import (
    InputSetVoAttribute,
)
from perun.connector.perun_openapi.model.input_set_vo_attributes import (
    InputSetVoAttributes,
)
from perun.connector.perun_openapi.model.input_set_vo_ban import InputSetVoBan
from perun.connector.perun_openapi.model.input_specific_member import (
    InputSpecificMember,
)
from perun.connector.perun_openapi.model.input_submit_application import (
    InputSubmitApplication,
)
from perun.connector.perun_openapi.model.input_unlock_services_on_destinations import (
    InputUnlockServicesOnDestinations,
)
from perun.connector.perun_openapi.model.input_update_application_mail import (
    InputUpdateApplicationMail,
)
from perun.connector.perun_openapi.model.input_update_ban import InputUpdateBan
from perun.connector.perun_openapi.model.input_update_ban1 import InputUpdateBan1
from perun.connector.perun_openapi.model.input_update_ban_for_facility import (
    InputUpdateBanForFacility,
)
from perun.connector.perun_openapi.model.input_update_category import (
    InputUpdateCategory,
)
from perun.connector.perun_openapi.model.input_update_consent_hub import (
    InputUpdateConsentHub,
)
from perun.connector.perun_openapi.model.input_update_facility import (
    InputUpdateFacility,
)
from perun.connector.perun_openapi.model.input_update_form import InputUpdateForm
from perun.connector.perun_openapi.model.input_update_form_items_for_group import (
    InputUpdateFormItemsForGroup,
)
from perun.connector.perun_openapi.model.input_update_form_items_for_vo import (
    InputUpdateFormItemsForVo,
)
from perun.connector.perun_openapi.model.input_update_group import InputUpdateGroup
from perun.connector.perun_openapi.model.input_update_publication import (
    InputUpdatePublication,
)
from perun.connector.perun_openapi.model.input_update_publication_system import (
    InputUpdatePublicationSystem,
)
from perun.connector.perun_openapi.model.input_update_resource import (
    InputUpdateResource,
)
from perun.connector.perun_openapi.model.input_update_resource_tag import (
    InputUpdateResourceTag,
)
from perun.connector.perun_openapi.model.input_update_service import InputUpdateService
from perun.connector.perun_openapi.model.input_update_services_package import (
    InputUpdateServicesPackage,
)
from perun.connector.perun_openapi.model.input_update_user import InputUpdateUser
from perun.connector.perun_openapi.model.input_update_vo import InputUpdateVo
from perun.connector.perun_openapi.model.item_texts import ItemTexts
from perun.connector.perun_openapi.model.mail_text import MailText
from perun.connector.perun_openapi.model.mail_type import MailType
from perun.connector.perun_openapi.model.member import Member
from perun.connector.perun_openapi.model.member_candidate import MemberCandidate
from perun.connector.perun_openapi.model.member_group_status import MemberGroupStatus
from perun.connector.perun_openapi.model.member_with_sponsors import MemberWithSponsors
from perun.connector.perun_openapi.model.members_order_column import MembersOrderColumn
from perun.connector.perun_openapi.model.members_page_query import MembersPageQuery
from perun.connector.perun_openapi.model.namespace_rules import NamespaceRules
from perun.connector.perun_openapi.model.new_apps import NewApps
from perun.connector.perun_openapi.model.owner import Owner
from perun.connector.perun_openapi.model.owner_type import OwnerType
from perun.connector.perun_openapi.model.paginated_audit_messages import (
    PaginatedAuditMessages,
)
from perun.connector.perun_openapi.model.paginated_rich_applications import (
    PaginatedRichApplications,
)
from perun.connector.perun_openapi.model.paginated_rich_groups import (
    PaginatedRichGroups,
)
from perun.connector.perun_openapi.model.paginated_rich_members import (
    PaginatedRichMembers,
)
from perun.connector.perun_openapi.model.paginated_rich_users import PaginatedRichUsers
from perun.connector.perun_openapi.model.perun_apps_config import PerunAppsConfig
from perun.connector.perun_openapi.model.perun_bean import PerunBean
from perun.connector.perun_openapi.model.perun_exception import PerunException
from perun.connector.perun_openapi.model.perun_policy import PerunPolicy
from perun.connector.perun_openapi.model.perun_principal import PerunPrincipal
from perun.connector.perun_openapi.model.publication import Publication
from perun.connector.perun_openapi.model.publication_for_gui import PublicationForGUI
from perun.connector.perun_openapi.model.publication_system import PublicationSystem
from perun.connector.perun_openapi.model.rt_message import RTMessage
from perun.connector.perun_openapi.model.resource import Resource
from perun.connector.perun_openapi.model.resource_state import ResourceState
from perun.connector.perun_openapi.model.resource_tag import ResourceTag
from perun.connector.perun_openapi.model.rich_application import RichApplication
from perun.connector.perun_openapi.model.rich_destination import RichDestination
from perun.connector.perun_openapi.model.rich_facility import RichFacility
from perun.connector.perun_openapi.model.rich_group import RichGroup
from perun.connector.perun_openapi.model.rich_member import RichMember
from perun.connector.perun_openapi.model.rich_resource import RichResource
from perun.connector.perun_openapi.model.rich_user import RichUser
from perun.connector.perun_openapi.model.rich_user_ext_source import RichUserExtSource
from perun.connector.perun_openapi.model.role_management_rules import (
    RoleManagementRules,
)
from perun.connector.perun_openapi.model.role_object import RoleObject
from perun.connector.perun_openapi.model.security_team import SecurityTeam
from perun.connector.perun_openapi.model.service import Service
from perun.connector.perun_openapi.model.service_attributes import ServiceAttributes
from perun.connector.perun_openapi.model.service_for_gui import ServiceForGUI
from perun.connector.perun_openapi.model.service_state import ServiceState
from perun.connector.perun_openapi.model.services_package import ServicesPackage
from perun.connector.perun_openapi.model.set_role_for_group import SetRoleForGroup
from perun.connector.perun_openapi.model.set_role_for_user import SetRoleForUser
from perun.connector.perun_openapi.model.set_role_with_group_complementary_object import (
    SetRoleWithGroupComplementaryObject,
)
from perun.connector.perun_openapi.model.set_role_with_group_complementary_objects import (
    SetRoleWithGroupComplementaryObjects,
)
from perun.connector.perun_openapi.model.set_role_with_user_complementary_object import (
    SetRoleWithUserComplementaryObject,
)
from perun.connector.perun_openapi.model.set_role_with_user_complementary_objects import (
    SetRoleWithUserComplementaryObjects,
)
from perun.connector.perun_openapi.model.simple_attribute import SimpleAttribute
from perun.connector.perun_openapi.model.sorting_order import SortingOrder
from perun.connector.perun_openapi.model.sponsor import Sponsor
from perun.connector.perun_openapi.model.sponsored_user_data import SponsoredUserData
from perun.connector.perun_openapi.model.task import Task
from perun.connector.perun_openapi.model.task_and_destination_id_object import (
    TaskAndDestinationIdObject,
)
from perun.connector.perun_openapi.model.task_and_destination_name_object import (
    TaskAndDestinationNameObject,
)
from perun.connector.perun_openapi.model.task_id_object import TaskIdObject
from perun.connector.perun_openapi.model.task_result import TaskResult
from perun.connector.perun_openapi.model.task_result_id_object import TaskResultIdObject
from perun.connector.perun_openapi.model.task_result_status import TaskResultStatus
from perun.connector.perun_openapi.model.task_status import TaskStatus
from perun.connector.perun_openapi.model.thanks import Thanks
from perun.connector.perun_openapi.model.thanks_for_gui import ThanksForGUI
from perun.connector.perun_openapi.model.type import Type
from perun.connector.perun_openapi.model.unset_role_for_group import UnsetRoleForGroup
from perun.connector.perun_openapi.model.unset_role_for_user import UnsetRoleForUser
from perun.connector.perun_openapi.model.unset_role_with_group_complementary_object import (
    UnsetRoleWithGroupComplementaryObject,
)
from perun.connector.perun_openapi.model.unset_role_with_group_complementary_objects import (
    UnsetRoleWithGroupComplementaryObjects,
)
from perun.connector.perun_openapi.model.unset_role_with_user_complementary_object import (
    UnsetRoleWithUserComplementaryObject,
)
from perun.connector.perun_openapi.model.unset_role_with_user_complementary_objects import (
    UnsetRoleWithUserComplementaryObjects,
)
from perun.connector.perun_openapi.model.user import User
from perun.connector.perun_openapi.model.user_ext_source import UserExtSource
from perun.connector.perun_openapi.model.users_order_column import UsersOrderColumn
from perun.connector.perun_openapi.model.users_page_query import UsersPageQuery
from perun.connector.perun_openapi.model.vo import Vo
from perun.connector.perun_openapi.model.vo_admin_roles import VoAdminRoles
from perun.connector.perun_openapi.model.vo_member_statuses import VoMemberStatuses



"""
    Perun RPC API

    Perun Remote Procedure Calls Application Programming Interface  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: perun@cesnet.cz
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from perun.connector.perun_openapi.api_client import ApiClient, Endpoint as _Endpoint
from perun.connector.perun_openapi.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types,
)
from perun.connector.perun_openapi.model.perun_apps_config import PerunAppsConfig
from perun.connector.perun_openapi.model.perun_exception import PerunException


class UtilsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_apps_config_endpoint = _Endpoint(
            settings={
                "response_type": (PerunAppsConfig,),
                "auth": ["BasicAuth", "BearerAuth"],
                "endpoint_path": "/json/utils/getAppsConfig",
                "operation_id": "get_apps_config",
                "http_method": "GET",
                "servers": None,
            },
            params_map={
                "all": [],
                "required": [],
                "nullable": [],
                "enum": [],
                "validation": [],
            },
            root_map={
                "validations": {},
                "allowed_values": {},
                "openapi_types": {},
                "attribute_map": {},
                "location_map": {},
                "collection_format_map": {},
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )
        self.get_gui_configuration_endpoint = _Endpoint(
            settings={
                "response_type": ({str: (str,)},),
                "auth": ["BasicAuth", "BearerAuth"],
                "endpoint_path": "/json/utils/getGuiConfiguration",
                "operation_id": "get_gui_configuration",
                "http_method": "GET",
                "servers": None,
            },
            params_map={
                "all": [],
                "required": [],
                "nullable": [],
                "enum": [],
                "validation": [],
            },
            root_map={
                "validations": {},
                "allowed_values": {},
                "openapi_types": {},
                "attribute_map": {},
                "location_map": {},
                "collection_format_map": {},
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )
        self.get_new_gui_alert_endpoint = _Endpoint(
            settings={
                "response_type": (str,),
                "auth": ["BasicAuth", "BearerAuth"],
                "endpoint_path": "/json/utils/getNewGuiAlert",
                "operation_id": "get_new_gui_alert",
                "http_method": "GET",
                "servers": None,
            },
            params_map={
                "all": [],
                "required": [],
                "nullable": [],
                "enum": [],
                "validation": [],
            },
            root_map={
                "validations": {},
                "allowed_values": {},
                "openapi_types": {},
                "attribute_map": {},
                "location_map": {},
                "collection_format_map": {},
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )
        self.get_perun_rpc_version_endpoint = _Endpoint(
            settings={
                "response_type": (str,),
                "auth": ["BasicAuth", "BearerAuth"],
                "endpoint_path": "/",
                "operation_id": "get_perun_rpc_version",
                "http_method": "GET",
                "servers": None,
            },
            params_map={
                "all": [],
                "required": [],
                "nullable": [],
                "enum": [],
                "validation": [],
            },
            root_map={
                "validations": {},
                "allowed_values": {},
                "openapi_types": {},
                "attribute_map": {},
                "location_map": {},
                "collection_format_map": {},
            },
            headers_map={
                "accept": ["text/plain"],
                "content_type": [],
            },
            api_client=api_client,
        )
        self.get_perun_statistics_endpoint = _Endpoint(
            settings={
                "response_type": ([str],),
                "auth": ["BasicAuth", "BearerAuth"],
                "endpoint_path": "/json/utils/getPerunStatistics",
                "operation_id": "get_perun_statistics",
                "http_method": "GET",
                "servers": None,
            },
            params_map={
                "all": [],
                "required": [],
                "nullable": [],
                "enum": [],
                "validation": [],
            },
            root_map={
                "validations": {},
                "allowed_values": {},
                "openapi_types": {},
                "attribute_map": {},
                "location_map": {},
                "collection_format_map": {},
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )
        self.get_perun_status_endpoint = _Endpoint(
            settings={
                "response_type": ([str],),
                "auth": ["BasicAuth", "BearerAuth"],
                "endpoint_path": "/json/utils/getPerunStatus",
                "operation_id": "get_perun_status",
                "http_method": "GET",
                "servers": None,
            },
            params_map={
                "all": [],
                "required": [],
                "nullable": [],
                "enum": [],
                "validation": [],
            },
            root_map={
                "validations": {},
                "allowed_values": {},
                "openapi_types": {},
                "attribute_map": {},
                "location_map": {},
                "collection_format_map": {},
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )
        self.get_perun_system_time_in_millis_endpoint = _Endpoint(
            settings={
                "response_type": (int,),
                "auth": ["BasicAuth", "BearerAuth"],
                "endpoint_path": "/json/utils/getPerunSystemTimeInMillis",
                "operation_id": "get_perun_system_time_in_millis",
                "http_method": "GET",
                "servers": None,
            },
            params_map={
                "all": [],
                "required": [],
                "nullable": [],
                "enum": [],
                "validation": [],
            },
            root_map={
                "validations": {},
                "allowed_values": {},
                "openapi_types": {},
                "attribute_map": {},
                "location_map": {},
                "collection_format_map": {},
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

    def get_apps_config(self, **kwargs):
        """Gets configuration of perun apps brandings and apps' domains  # noqa: E501

        Returns object of type PerunAppsConfig  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_apps_config(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            PerunAppsConfig
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs["async_req"] = kwargs.get("async_req", False)
        kwargs["_return_http_data_only"] = kwargs.get("_return_http_data_only", True)
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")
        kwargs["_request_auths"] = kwargs.get("_request_auths", None)
        return self.get_apps_config_endpoint.call_with_http_info(**kwargs)

    def get_gui_configuration(self, **kwargs):
        """Gets perun-web-gui.properties as Map<String,String>  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_gui_configuration(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (str,)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs["async_req"] = kwargs.get("async_req", False)
        kwargs["_return_http_data_only"] = kwargs.get("_return_http_data_only", True)
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")
        kwargs["_request_auths"] = kwargs.get("_request_auths", None)
        return self.get_gui_configuration_endpoint.call_with_http_info(**kwargs)

    def get_new_gui_alert(self, **kwargs):
        """Gets new GUI alert (banner html content) for the brand of incoming request.  # noqa: E501

        Returns new GUI alert  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_new_gui_alert(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs["async_req"] = kwargs.get("async_req", False)
        kwargs["_return_http_data_only"] = kwargs.get("_return_http_data_only", True)
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")
        kwargs["_request_auths"] = kwargs.get("_request_auths", None)
        return self.get_new_gui_alert_endpoint.call_with_http_info(**kwargs)

    def get_perun_rpc_version(self, **kwargs):
        """Gets Perun runtime status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_perun_rpc_version(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs["async_req"] = kwargs.get("async_req", False)
        kwargs["_return_http_data_only"] = kwargs.get("_return_http_data_only", True)
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")
        kwargs["_request_auths"] = kwargs.get("_request_auths", None)
        return self.get_perun_rpc_version_endpoint.call_with_http_info(**kwargs)

    def get_perun_statistics(self, **kwargs):
        """Gets Perun runtime statistics  # noqa: E501

        Returns list of strings which looks like this \"Timestamp: '2019-11-14 10:46:39.613'\", \"USERS: '39927'\", \"FACILITIES: '552'\", \"DESTINATIONS: '2568'\", \"VOS: '341'\", \"RESOURCES: '2560'\", \"GROUPS: '2300'\", \"AUDITMESSAGES: '7333237'\"   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_perun_statistics(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [str]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs["async_req"] = kwargs.get("async_req", False)
        kwargs["_return_http_data_only"] = kwargs.get("_return_http_data_only", True)
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")
        kwargs["_request_auths"] = kwargs.get("_request_auths", None)
        return self.get_perun_statistics_endpoint.call_with_http_info(**kwargs)

    def get_perun_status(self, **kwargs):
        """Gets Perun runtime status  # noqa: E501

        Returns list of strings which looks like this \"Version of Perun: 3.8.6\", \"Version of PerunDB: 3.1.55\", \"Version of Servlet: Apache Tomcat/9.0.16 (Debian)\", \"Version of DB-driver: PostgreSQL JDBC Driver-42.2.8\", \"Version of DB: PostgreSQL-12.0 (Debian 12.0-2.pgdg100+1)\", \"Version of Java platform: 11.0.5\", \"AuditerConsumer: '127.0.0.1:6071' with last processed id='23463958'\", \"AuditerConsumer: 'ldapcConsumer' with last processed id='23463958'\", \"AuditerConsumer: 'notifications' with last processed id='23463952'\", \"LastMessageId: 23463958\", \"Timestamp: 2019-11-14 10:12:30.99\"   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_perun_status(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [str]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs["async_req"] = kwargs.get("async_req", False)
        kwargs["_return_http_data_only"] = kwargs.get("_return_http_data_only", True)
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")
        kwargs["_request_auths"] = kwargs.get("_request_auths", None)
        return self.get_perun_status_endpoint.call_with_http_info(**kwargs)

    def get_perun_system_time_in_millis(self, **kwargs):
        """Gets Perun system time in milliseconds since the epoch  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_perun_system_time_in_millis(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            int
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs["async_req"] = kwargs.get("async_req", False)
        kwargs["_return_http_data_only"] = kwargs.get("_return_http_data_only", True)
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")
        kwargs["_request_auths"] = kwargs.get("_request_auths", None)
        return self.get_perun_system_time_in_millis_endpoint.call_with_http_info(
            **kwargs
        )



"""
    Perun RPC API

    Perun Remote Procedure Calls Application Programming Interface  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: perun@cesnet.cz
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from perun.connector.perun_openapi.api_client import ApiClient, Endpoint as _Endpoint
from perun.connector.perun_openapi.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types,
)
from perun.connector.perun_openapi.model.input_create_owner import InputCreateOwner
from perun.connector.perun_openapi.model.owner import Owner
from perun.connector.perun_openapi.model.perun_exception import PerunException


class OwnersManagerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_owner_endpoint = _Endpoint(
            settings={
                "response_type": (Owner,),
                "auth": ["BasicAuth", "BearerAuth"],
                "endpoint_path": "/json/ownersManager/createOwner",
                "operation_id": "create_owner",
                "http_method": "POST",
                "servers": None,
            },
            params_map={
                "all": [
                    "input_create_owner",
                ],
                "required": [
                    "input_create_owner",
                ],
                "nullable": [],
                "enum": [],
                "validation": [],
            },
            root_map={
                "validations": {},
                "allowed_values": {},
                "openapi_types": {
                    "input_create_owner": (InputCreateOwner,),
                },
                "attribute_map": {},
                "location_map": {
                    "input_create_owner": "body",
                },
                "collection_format_map": {},
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": ["application/json"],
            },
            api_client=api_client,
        )
        self.delete_owner_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["BasicAuth", "BearerAuth"],
                "endpoint_path": "/urlinjsonout/ownersManager/deleteOwner",
                "operation_id": "delete_owner",
                "http_method": "POST",
                "servers": None,
            },
            params_map={
                "all": [
                    "owner",
                    "force",
                ],
                "required": [
                    "owner",
                ],
                "nullable": [],
                "enum": [],
                "validation": [],
            },
            root_map={
                "validations": {},
                "allowed_values": {},
                "openapi_types": {
                    "owner": (int,),
                    "force": (bool,),
                },
                "attribute_map": {
                    "owner": "owner",
                    "force": "force",
                },
                "location_map": {
                    "owner": "query",
                    "force": "query",
                },
                "collection_format_map": {},
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )
        self.delete_owners_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["BasicAuth", "BearerAuth"],
                "endpoint_path": "/urlinjsonout/ownersManager/deleteOwners",
                "operation_id": "delete_owners",
                "http_method": "POST",
                "servers": None,
            },
            params_map={
                "all": [
                    "owners",
                    "force",
                ],
                "required": [
                    "owners",
                ],
                "nullable": [],
                "enum": [],
                "validation": [],
            },
            root_map={
                "validations": {},
                "allowed_values": {},
                "openapi_types": {
                    "owners": ([int],),
                    "force": (bool,),
                },
                "attribute_map": {
                    "owners": "owners[]",
                    "force": "force",
                },
                "location_map": {
                    "owners": "query",
                    "force": "query",
                },
                "collection_format_map": {
                    "owners": "multi",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )
        self.get_all_owners_endpoint = _Endpoint(
            settings={
                "response_type": ([Owner],),
                "auth": ["BasicAuth", "BearerAuth"],
                "endpoint_path": "/json/ownersManager/getOwners",
                "operation_id": "get_all_owners",
                "http_method": "GET",
                "servers": None,
            },
            params_map={
                "all": [],
                "required": [],
                "nullable": [],
                "enum": [],
                "validation": [],
            },
            root_map={
                "validations": {},
                "allowed_values": {},
                "openapi_types": {},
                "attribute_map": {},
                "location_map": {},
                "collection_format_map": {},
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )
        self.get_owner_by_id_endpoint = _Endpoint(
            settings={
                "response_type": (Owner,),
                "auth": ["BasicAuth", "BearerAuth"],
                "endpoint_path": "/json/ownersManager/getOwnerById",
                "operation_id": "get_owner_by_id",
                "http_method": "GET",
                "servers": None,
            },
            params_map={
                "all": [
                    "id",
                ],
                "required": [
                    "id",
                ],
                "nullable": [],
                "enum": [],
                "validation": [],
            },
            root_map={
                "validations": {},
                "allowed_values": {},
                "openapi_types": {
                    "id": (int,),
                },
                "attribute_map": {
                    "id": "id",
                },
                "location_map": {
                    "id": "query",
                },
                "collection_format_map": {},
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )
        self.get_owner_by_name_endpoint = _Endpoint(
            settings={
                "response_type": (Owner,),
                "auth": ["BasicAuth", "BearerAuth"],
                "endpoint_path": "/json/ownersManager/getOwnerByName",
                "operation_id": "get_owner_by_name",
                "http_method": "GET",
                "servers": None,
            },
            params_map={
                "all": [
                    "owner",
                ],
                "required": [
                    "owner",
                ],
                "nullable": [],
                "enum": [],
                "validation": [],
            },
            root_map={
                "validations": {},
                "allowed_values": {},
                "openapi_types": {
                    "owner": (str,),
                },
                "attribute_map": {
                    "owner": "owner",
                },
                "location_map": {
                    "owner": "query",
                },
                "collection_format_map": {},
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

    def create_owner(self, input_create_owner, **kwargs):
        """Creates a new owner.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_owner(input_create_owner, async_req=True)
        >>> result = thread.get()

        Args:
            input_create_owner (InputCreateOwner):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            Owner
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs["async_req"] = kwargs.get("async_req", False)
        kwargs["_return_http_data_only"] = kwargs.get("_return_http_data_only", True)
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")
        kwargs["_request_auths"] = kwargs.get("_request_auths", None)
        kwargs["input_create_owner"] = input_create_owner
        return self.create_owner_endpoint.call_with_http_info(**kwargs)

    def delete_owner(self, owner, **kwargs):
        """Deletes Owner specified by id. Returns null.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_owner(owner, async_req=True)
        >>> result = thread.get()

        Args:
            owner (int): id of Owner

        Keyword Args:
            force (bool): If true, delete entity forcefully.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs["async_req"] = kwargs.get("async_req", False)
        kwargs["_return_http_data_only"] = kwargs.get("_return_http_data_only", True)
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")
        kwargs["_request_auths"] = kwargs.get("_request_auths", None)
        kwargs["owner"] = owner
        return self.delete_owner_endpoint.call_with_http_info(**kwargs)

    def delete_owners(self, owners, **kwargs):
        """Deletes owners by ids. Returns null.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_owners(owners, async_req=True)
        >>> result = thread.get()

        Args:
            owners ([int]): list of owner ids

        Keyword Args:
            force (bool): If true, delete entity forcefully.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs["async_req"] = kwargs.get("async_req", False)
        kwargs["_return_http_data_only"] = kwargs.get("_return_http_data_only", True)
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")
        kwargs["_request_auths"] = kwargs.get("_request_auths", None)
        kwargs["owners"] = owners
        return self.delete_owners_endpoint.call_with_http_info(**kwargs)

    def get_all_owners(self, **kwargs):
        """Returns all owners.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all_owners(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [Owner]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs["async_req"] = kwargs.get("async_req", False)
        kwargs["_return_http_data_only"] = kwargs.get("_return_http_data_only", True)
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")
        kwargs["_request_auths"] = kwargs.get("_request_auths", None)
        return self.get_all_owners_endpoint.call_with_http_info(**kwargs)

    def get_owner_by_id(self, id, **kwargs):
        """Returns Owner by its id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_owner_by_id(id, async_req=True)
        >>> result = thread.get()

        Args:
            id (int): numeric id

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            Owner
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs["async_req"] = kwargs.get("async_req", False)
        kwargs["_return_http_data_only"] = kwargs.get("_return_http_data_only", True)
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")
        kwargs["_request_auths"] = kwargs.get("_request_auths", None)
        kwargs["id"] = id
        return self.get_owner_by_id_endpoint.call_with_http_info(**kwargs)

    def get_owner_by_name(self, owner, **kwargs):
        """Returns Owner by its name.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_owner_by_name(owner, async_req=True)
        >>> result = thread.get()

        Args:
            owner (str): name of Owner

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            Owner
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs["async_req"] = kwargs.get("async_req", False)
        kwargs["_return_http_data_only"] = kwargs.get("_return_http_data_only", True)
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")
        kwargs["_request_auths"] = kwargs.get("_request_auths", None)
        kwargs["owner"] = owner
        return self.get_owner_by_name_endpoint.call_with_http_info(**kwargs)
